==> image-saas-domain-0.0.759-sources.jar: com/xforceplus/ultraman/app/imagesaas/metadata/PageMeta.java <==
package com.xforceplus.ultraman.app.imagesaas.metadata;

/**
 *
 * @author ultraman
 * @since 2022-05-09
 */

public class PageMeta {
    public interface PublicTicket {
        static String code() {
            return "publicTicket";
        }
        static String name() {
            return "未挂接影像池";
        }
    }
    public interface ArchivesCover {
        static String code() {
            return "archivesCover";
        }
        static String name() {
            return "封面设置";
        }
    }
    public interface Scan {
        static String code() {
            return "scan";
        }
        static String name() {
            return "影像采集";
        }
    }
    public interface ConfigSettings {
        static String code() {
            return "configSettings";
        }
        static String name() {
            return "系统配置";
        }
    }
    public interface ScanGroup {
        static String code() {
            return "scanGroup";
        }
        static String name() {
            return "影像采集小组";
        }
    }
    public interface ScanManage {
        static String code() {
            return "scanManage";
        }
        static String name() {
            return "影像管理";
        }
    }
    public interface ScanCheck {
        static String code() {
            return "scanCheck";
        }
        static String name() {
            return "影像校验";
        }
    }
    public interface Label {
        static String code() {
            return "label";
        }
        static String name() {
            return "我的标签";
        }
    }
    public interface DiscernRule {
        static String code() {
            return "discernRule";
        }
        static String name() {
            return "识别规则";
        }
    }
    public interface ReUpload {
        static String code() {
            return "reUpload";
        }
        static String name() {
            return "重新推送";
        }
    }
    public interface CompanyTicket {
        static String code() {
            return "companyTicket";
        }
        static String name() {
            return "公共单证池";
        }
    }
    public interface AdvancePayment {
        static String code() {
            return "advancePayment";
        }
        static String name() {
            return "预付款";
        }
    }
    public interface Logistics {
        static String code() {
            return "logistics";
        }
        static String name() {
            return "物流待寄送";
        }
    }
    public interface PersonTicket {
        static String code() {
            return "personTicket";
        }
        static String name() {
            return "个人单证池";
        }
    }
    public interface HookTicketPool {
        static String code() {
            return "hookTicketPool";
        }
        static String name() {
            return "待挂接单证池";
        }
    }
    public interface ConfigDictionary {
        static String code() {
            return "configDictionary";
        }
        static String name() {
            return "数据字典";
        }
    }
    public interface ElectricTicketFile {
        static String code() {
            return "electricTicketFile";
        }
        static String name() {
            return "电票源文件";
        }
    }
    public interface DocumentSign {
        static String code() {
            return "documentSign";
        }
        static String name() {
            return "单证签收";
        }
    }
    public interface BackTicket {
        static String code() {
            return "backTicket";
        }
        static String name() {
            return "退回代办";
        }
    }
    public interface ReceiveFiles {
        static String code() {
            return "receiveFiles";
        }
        static String name() {
            return "第三方文件影像";
        }
    }
    public interface TodoTask {
        static String code() {
            return "todoTask";
        }
        static String name() {
            return "待办任务";
        }
    }
    public interface TaskQueue {
        static String code() {
            return "taskQueue";
        }
        static String name() {
            return "任务队列";
        }
    }
    public interface Operation {
        static String code() {
            return "operation";
        }
        static String name() {
            return "功能运维";
        }
    }
    public interface SystemLabel {
        static String code() {
            return "systemLabel";
        }
        static String name() {
            return "系统标签";
        }
    }
    public interface ScanTodo {
        static String code() {
            return "scanTodo";
        }
        static String name() {
            return "扫描待办";
        }
    }
    public interface TodoImagePool {
        static String code() {
            return "todoImagePool";
        }
        static String name() {
            return "待办影像池";
        }
    }
    public interface OperationLog {
        static String code() {
            return "operationLog";
        }
        static String name() {
            return "功能运维日志";
        }
    }
    public interface PersonTicketH5 {
        static String code() {
            return "personTicketH5";
        }
        static String name() {
            return "h5个人单证池";
        }
    }
    public interface AllBillPool {
        static String code() {
            return "allBillPool";
        }
        static String name() {
            return "全量单据池";
        }
    }
    public interface AllTicketPool {
        static String code() {
            return "allTicketPool";
        }
        static String name() {
            return "全量影像池";
        }
    }
    public interface ImageFile {
        static String code() {
            return "imageFile";
        }
        static String name() {
            return "影像文件";
        }
    }
    public interface CompareScan {
        static String code() {
            return "compareScan";
        }
        static String name() {
            return "稽核采集";
        }
    }
    public interface CompareBill {
        static String code() {
            return "compareBill";
        }
        static String name() {
            return "收单稽核";
        }
    }
    public interface CompareScanH5 {
        static String code() {
            return "compareScanH5";
        }
        static String name() {
            return "h5稽核采集";
        }
    }
    public interface BackLog {
        static String code() {
            return "backLog";
        }
        static String name() {
            return "退回记录";
        }
    }
    public interface BatchNumberRule {
        static String code() {
            return "batchNumberRule";
        }
        static String name() {
            return "批次号规则";
        }
    }
    public interface PersonBillPool {
        static String code() {
            return "personBillPool";
        }
        static String name() {
            return "个人单据池";
        }
    }
    public interface TicketDetail {
        static String code() {
            return "ticketDetail";
        }
        static String name() {
            return "机票明细(废弃)";
        }
    }
    public interface TicketPlaneDetail {
        static String code() {
            return "ticketPlaneDetail";
        }
        static String name() {
            return "h5飞机票明细";
        }
    }
    public interface InvoiceScan {
        static String code() {
            return "invoiceScan";
        }
        static String name() {
            return "发票采集";
        }
    }
    public interface InvoiceScanH5 {
        static String code() {
            return "invoiceScanH5";
        }
        static String name() {
            return "发票采集-移动端";
        }
    }
    public interface HookTicketH5 {
        static String code() {
            return "hookTicketH5";
        }
        static String name() {
            return "h5认领池";
        }
    }
    public interface BillH5 {
        static String code() {
            return "billH5";
        }
        static String name() {
            return "单据采集H5";
        }
    }
    public interface NonInvoice {
        static String code() {
            return "nonInvoice";
        }
        static String name() {
            return "非增票池";
        }
    }
    public interface TicketTrain {
        static String code() {
            return "ticketTrain";
        }
        static String name() {
            return "非增票池——火车票";
        }
    }
    public interface TicketPlane {
        static String code() {
            return "ticketPlane";
        }
        static String name() {
            return "非增票池——行程单";
        }
    }
    public interface TicketBus {
        static String code() {
            return "ticketBus";
        }
        static String name() {
            return "非增票池——客运汽车船";
        }
    }
    public interface TicketToll {
        static String code() {
            return "ticketToll";
        }
        static String name() {
            return "非增票池——过路费发票";
        }
    }
    public interface TicketTaxi {
        static String code() {
            return "ticketTaxi";
        }
        static String name() {
            return "非增票池——出租车票";
        }
    }
    public interface TicketQuota {
        static String code() {
            return "ticketQuota";
        }
        static String name() {
            return "非增票池——定额发票";
        }
    }
    public interface TicketMachine {
        static String code() {
            return "ticketMachine";
        }
        static String name() {
            return "非增票池——通用机打发票";
        }
    }
    public interface TicketInvoiceDetail {
        static String code() {
            return "ticketInvoiceDetail";
        }
        static String name() {
            return "增值税发票明细";
        }
    }
    public interface TicketInvoiceDetailH5 {
        static String code() {
            return "ticketInvoiceDetailH5";
        }
        static String name() {
            return "h5增值税发票明细";
        }
    }
    public interface TicketCustomsPaymentDetail {
        static String code() {
            return "ticketCustomsPaymentDetail";
        }
        static String name() {
            return "海关缴款书明细";
        }
    }
}

==> image-saas-domain-0.0.806-sources.jar: com/xforceplus/ultraman/app/imagesaas/metadata/PageMeta.java <==
package com.xforceplus.ultraman.app.imagesaas.metadata;

/**
 *
 * @author ultraman
 * @since 2022-05-26
 */

public class PageMeta {
    public interface PublicTicket {
        static String code() {
            return "publicTicket";
        }
        static String name() {
            return "未挂接影像池";
        }
    }
    public interface ArchivesCover {
        static String code() {
            return "archivesCover";
        }
        static String name() {
            return "封面设置";
        }
    }
    public interface Scan {
        static String code() {
            return "scan";
        }
        static String name() {
            return "影像采集";
        }
    }
    public interface ConfigSettings {
        static String code() {
            return "configSettings";
        }
        static String name() {
            return "系统配置";
        }
    }
    public interface ScanGroup {
        static String code() {
            return "scanGroup";
        }
        static String name() {
            return "影像采集小组";
        }
    }
    public interface ScanManage {
        static String code() {
            return "scanManage";
        }
        static String name() {
            return "影像管理";
        }
    }
    public interface ScanCheck {
        static String code() {
            return "scanCheck";
        }
        static String name() {
            return "影像校验";
        }
    }
    public interface Label {
        static String code() {
            return "label";
        }
        static String name() {
            return "我的标签";
        }
    }
    public interface DiscernRule {
        static String code() {
            return "discernRule";
        }
        static String name() {
            return "识别规则";
        }
    }
    public interface ReUpload {
        static String code() {
            return "reUpload";
        }
        static String name() {
            return "重新推送";
        }
    }
    public interface CompanyTicket {
        static String code() {
            return "companyTicket";
        }
        static String name() {
            return "公共单证池";
        }
    }
    public interface AdvancePayment {
        static String code() {
            return "advancePayment";
        }
        static String name() {
            return "预付款";
        }
    }
    public interface Logistics {
        static String code() {
            return "logistics";
        }
        static String name() {
            return "物流待寄送";
        }
    }
    public interface PersonTicket {
        static String code() {
            return "personTicket";
        }
        static String name() {
            return "个人单证池";
        }
    }
    public interface HookTicketPool {
        static String code() {
            return "hookTicketPool";
        }
        static String name() {
            return "待挂接单证池";
        }
    }
    public interface ConfigDictionary {
        static String code() {
            return "configDictionary";
        }
        static String name() {
            return "数据字典";
        }
    }
    public interface ElectricTicketFile {
        static String code() {
            return "electricTicketFile";
        }
        static String name() {
            return "电票源文件";
        }
    }
    public interface DocumentSign {
        static String code() {
            return "documentSign";
        }
        static String name() {
            return "单证签收";
        }
    }
    public interface BackTicket {
        static String code() {
            return "backTicket";
        }
        static String name() {
            return "退回代办";
        }
    }
    public interface ReceiveFiles {
        static String code() {
            return "receiveFiles";
        }
        static String name() {
            return "第三方文件影像";
        }
    }
    public interface TodoTask {
        static String code() {
            return "todoTask";
        }
        static String name() {
            return "待办任务";
        }
    }
    public interface TaskQueue {
        static String code() {
            return "taskQueue";
        }
        static String name() {
            return "任务队列";
        }
    }
    public interface Operation {
        static String code() {
            return "operation";
        }
        static String name() {
            return "功能运维";
        }
    }
    public interface SystemLabel {
        static String code() {
            return "systemLabel";
        }
        static String name() {
            return "系统标签";
        }
    }
    public interface ScanTodo {
        static String code() {
            return "scanTodo";
        }
        static String name() {
            return "扫描待办";
        }
    }
    public interface TodoImagePool {
        static String code() {
            return "todoImagePool";
        }
        static String name() {
            return "待办影像池";
        }
    }
    public interface OperationLog {
        static String code() {
            return "operationLog";
        }
        static String name() {
            return "功能运维日志";
        }
    }
    public interface PersonTicketH5 {
        static String code() {
            return "personTicketH5";
        }
        static String name() {
            return "h5个人单证池";
        }
    }
    public interface AllBillPool {
        static String code() {
            return "allBillPool";
        }
        static String name() {
            return "全量单据池";
        }
    }
    public interface AllTicketPool {
        static String code() {
            return "allTicketPool";
        }
        static String name() {
            return "全量影像池";
        }
    }
    public interface ImageFile {
        static String code() {
            return "imageFile";
        }
        static String name() {
            return "影像文件";
        }
    }
    public interface CompareScan {
        static String code() {
            return "compareScan";
        }
        static String name() {
            return "稽核采集";
        }
    }
    public interface CompareBill {
        static String code() {
            return "compareBill";
        }
        static String name() {
            return "收单稽核";
        }
    }
    public interface CompareScanH5 {
        static String code() {
            return "compareScanH5";
        }
        static String name() {
            return "h5稽核采集";
        }
    }
    public interface BackLog {
        static String code() {
            return "backLog";
        }
        static String name() {
            return "退回记录";
        }
    }
    public interface BatchNumberRule {
        static String code() {
            return "batchNumberRule";
        }
        static String name() {
            return "批次号规则";
        }
    }
    public interface PersonBillPool {
        static String code() {
            return "personBillPool";
        }
        static String name() {
            return "个人单据池";
        }
    }
    public interface TicketDetail {
        static String code() {
            return "ticketDetail";
        }
        static String name() {
            return "机票明细(废弃)";
        }
    }
    public interface TicketPlaneDetail {
        static String code() {
            return "ticketPlaneDetail";
        }
        static String name() {
            return "h5飞机票明细";
        }
    }
    public interface InvoiceScan {
        static String code() {
            return "invoiceScan";
        }
        static String name() {
            return "发票采集";
        }
    }
    public interface InvoiceScanH5 {
        static String code() {
            return "invoiceScanH5";
        }
        static String name() {
            return "发票采集-移动端";
        }
    }
    public interface HookTicketH5 {
        static String code() {
            return "hookTicketH5";
        }
        static String name() {
            return "h5认领池";
        }
    }
    public interface BillH5 {
        static String code() {
            return "billH5";
        }
        static String name() {
            return "单据采集H5";
        }
    }
    public interface NonInvoice {
        static String code() {
            return "nonInvoice";
        }
        static String name() {
            return "非增票池";
        }
    }
    public interface TicketInvoiceDetail {
        static String code() {
            return "ticketInvoiceDetail";
        }
        static String name() {
            return "增值税发票明细";
        }
    }
    public interface TicketInvoiceDetailH5 {
        static String code() {
            return "ticketInvoiceDetailH5";
        }
        static String name() {
            return "h5增值税发票明细";
        }
    }
    public interface TicketCustomsPaymentDetail {
        static String code() {
            return "ticketCustomsPaymentDetail";
        }
        static String name() {
            return "海关缴款书明细";
        }
    }
    public interface CheckSystemConfig {
        static String code() {
            return "checkSystemConfig";
        }
        static String name() {
            return "检测系统配置";
        }
    }
}
